==> isis-fish-4.1.1.1-sources.jar: fr/ifremer/isisfish/ui/script/action/CancelAction.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: CancelAction.java 3124 2010-11-29 18:14:09Z chatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2005 - 2010 Ifremer, Code Lutin, Cedric Pineau, Benjamin Poussin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 2 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-2.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.script.action;

import fr.ifremer.isisfish.ui.util.IsisAction;

import javax.swing.JDialog;
import java.awt.event.ActionEvent;

/**
 * Cancel action. Do nothing, just close current dialog.
 * 
 * @author chatellier
 * @version $Revision: 3124 $
 * 
 * Last update : $Date: 2010-11-29 19:14:09 +0100 (Mon, 29 Nov 2010) $
 * By : $Author: chatellier $
 * 
 * @deprecated C'est pas evident de faire des Actions swing avec jaxx
 */
public class CancelAction extends IsisAction {
    
    /** serialVersionUID. */
    private static final long serialVersionUID = 2536223593370089763L;

    /**
     * Constructor.
     * 
     * @param dialog dialog to close on action performed
     */
    public CancelAction(JDialog dialog) {
        super(dialog);
    }

    @Override
    protected boolean prepare() {
        return true;
    }

    @Override
    protected void perform(ActionEvent e) {
        //nothing special to do
    }
}

==> isis-fish-4.3.0.2-20140616.104318-1-sources.jar: fr/ifremer/isisfish/ui/script/action/CancelAction.java <==
/*
 * #%L
 * IsisFish
 * 
 * $Id: CancelAction.java 3798 2012-10-30 10:39:32Z echatellier $
 * $HeadURL$
 * %%
 * Copyright (C) 2005 - 2010 Ifremer, Code Lutin, Cedric Pineau, Benjamin Poussin
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the 
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public 
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/gpl-3.0.html>.
 * #L%
 */

package fr.ifremer.isisfish.ui.script.action;

import fr.ifremer.isisfish.ui.util.IsisAction;

import javax.swing.JDialog;
import java.awt.event.ActionEvent;

/**
 * Cancel action. Do nothing, just close current dialog.
 * 
 * @author chatellier
 * @version $Revision: 3798 $
 * 
 * Last update : $Date: 2012-10-30 11:39:32 +0100 (mar. 30 oct. 2012) $
 * By : $Author: echatellier $
 * 
 * @deprecated C'est pas evident de faire des Actions swing avec jaxx
 */
public class CancelAction extends IsisAction {
    
    /** serialVersionUID. */
    private static final long serialVersionUID = 2536223593370089763L;

    /**
     * Constructor.
     * 
     * @param dialog dialog to close on action performed
     */
    public CancelAction(JDialog dialog) {
        super(dialog);
    }

    @Override
    protected boolean prepare() {
        return true;
    }

    @Override
    protected void perform(ActionEvent e) {
        //nothing special to do
    }
}
